=======================
 Peony's documentation
=======================

Peony is an asynchronous Twitter API client for Python 3.5+.

If you encounter an error after updating Peony check out the :ref:`breaking_changes` section.


.. toctree::
    :caption: Usage

    usage/quickstart
    usage/access
    usage/media
    usage/iterators
    usage/tasks
    usage/streams


.. toctree::
    :caption: Advanced Usage

    adv_usage/install
    adv_usage/api
    adv_usage/oauth2
    adv_usage/loads
    adv_usage/error_handler
    adv_usage/session


.. toctree::
    :caption: Changes

    changes


.. toctree::
    :caption: Modules
    :maxdepth: 4

    peony

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
